@@ -1,7 +1,7 @@
 from .aws_sig_v4 import AWSSigV4
 from .base_client import BaseClient
 from .client import Client
-from .helpers import fill_query_params, sp_endpoint, decrypt_aes, encrypt_aes, create_md5
+from .helpers import fill_query_params, sp_endpoint, create_md5
 from .marketplaces import Marketplaces
 from .exceptions import SellingApiException
 from .exceptions import SellingApiBadRequestException
@@ -47,8 +47,6 @@ __all__ = [
     'BuyerType',
     'FulfillmentChannel',
     'deprecated',
-    'decrypt_aes',
-    'encrypt_aes',
     'NotificationType',
     'CredentialProvider',
     'MissingCredentials'
