@@ -1,11 +1,6 @@
 from io import BytesIO
-
-from Crypto.Util.Padding import pad
 import hashlib
 
-import base64
-from Crypto.Cipher import AES
-
 
 def fill_query_params(query, *args):
     return query.format(*args)
@@ -26,31 +21,6 @@ def sp_endpoint(path, method='GET'):
     return decorator
 
 
-def encrypt_aes(file_or_bytes_io, key, iv):
-    key = base64.b64decode(key)
-    iv = base64.b64decode(iv)
-    aes = AES.new(key, AES.MODE_CBC, iv)
-    try:
-        if isinstance(file_or_bytes_io, BytesIO):
-            return aes.encrypt(pad(file_or_bytes_io.read(), 16))
-        return aes.encrypt(pad(bytes(file_or_bytes_io.read(), encoding='iso-8859-1'), 16))
-    except UnicodeEncodeError:
-        file_or_bytes_io.seek(0)
-        return aes.encrypt(pad(bytes(file_or_bytes_io.read(), encoding='utf-8'), 16))
-    except TypeError:
-        file_or_bytes_io.seek(0)
-        return aes.encrypt(pad(file_or_bytes_io.read(), 16))
-
-
-def decrypt_aes(content, key, iv):
-    key = base64.b64decode(key)
-    iv = base64.b64decode(iv)
-    decrypter = AES.new(key, AES.MODE_CBC, iv)
-    decrypted = decrypter.decrypt(content)
-    padding_bytes = decrypted[-1]
-    return decrypted[:-padding_bytes]
-
-
 def create_md5(file):
     hash_md5 = hashlib.md5()
     if isinstance(file, BytesIO):
